@@ -217,6 +217,10 @@ eel_mime_add_application (const char *mime_type,
 	char *basename;
 	char *desktop_text;
 	int i;
+
+	if (mime_type == NULL) {
+		return NULL;
+	}
 	
 	if (!ensure_application_dir ()) {
 		return NULL;
@@ -252,7 +256,7 @@ eel_mime_add_application (const char *mime_type,
 		command_line, needs_terminal ? "true" : "false");
 
 	if (write_desktop_file (filename, desktop_text)) {
-		ret = gnome_vfs_mime_application_new_from_id (basename);
+		ret = gnome_vfs_mime_application_new_from_desktop_id (basename);
 		run_update_command ("update-desktop-database", "applications");
 	} else {
 		ret = NULL;
@@ -702,6 +706,10 @@ eel_mime_check_for_duplicates (const char *mime_type,
 	gchar **argv;
 	gint argc;
 
+	if (mime_type == NULL) {
+		return NULL;
+	}
+	
 	applications = gnome_vfs_mime_get_all_applications (mime_type);
 	if (applications == NULL) {
 		return NULL;
@@ -735,7 +743,7 @@ eel_mime_check_for_duplicates (const char *mime_type,
 		application = list->data;
 		/* We do a parsing of the application command and see if it's
 		 * identical to the command being passed in. */
-		g_shell_parse_argv (application->command,
+		g_shell_parse_argv (gnome_vfs_mime_application_get_exec (application),
 				    &app_argc, &app_argv, NULL);
 		if (app_argv == NULL) {
 			continue;
